#!/bin/bash
#
# This file is included by /etc/mysql/debian-start
#

LOGGER_INFO="logger -p daemon.info -i -t$0 --"
LOGGER_WARN="logger -p daemon.warn -i -t$0 --"

function mycheck() {
  set -e
  set -u

  # Now, as the server seems to be up, check all unclosed tables.
  # But do it in the background to not stall the boot process.
  echo "Checking for crashed MySQL tables in the background." | $LOGGER_INFO

  # Checking for $? is unreliable so the size of the output is checked.
  # Some table handlers like HEAP do not support CHECK TABLE.
  tempfile=`tempfile`
  LC_ALL=C $MYCHECK $MYCHECK_PARAMS \
    2>&1 \
    | perl -e '$_=join("", <>); s/^[^\n]+\n(error|note)\s+: The (handler|storage engine) for the table doesn.t support check\n//smg;print;' \
    > $tempfile
  if [ -s $tempfile ]; then
    (
      /bin/echo -e "\n" \
        "Improperly closed tables are also reported if clients are accessing\n" \
 	"the tables *now*. A list of current connections is below.\n";
       $MYADMIN processlist status
    ) >> $tempfile
    # Check for presence as a dependency on mailx would require an MTA.
    if [ -x /usr/bin/mailx ]; then mailx -e -s"$MYCHECK_SUBJECT" root < $tempfile; fi
    (echo "$MYCHECK_SUBJECT"; cat $tempfile) | $LOGGER_WARN
  fi
  rm $tempfile
}
